@@ -9,6 +9,7 @@ IGNORE_NONE_VALUES = "_ignore_none"
 SERIALIZATION_MAPPER = "_serialization_mapper"
 DESERIALIZATION_MAPPER = "_deserialization_mapper"
 ENABLE_UNDEFINED = "_enable_undefined_value"
+DISABLE_PROTECTION = "_disable_protection"
 
 SPECIAL_ATTRIBUTES = {
     REQUIRED_FIELDS,
@@ -19,6 +20,7 @@ SPECIAL_ATTRIBUTES = {
     SERIALIZATION_MAPPER,
     DESERIALIZATION_MAPPER,
     IGNORE_NONE_VALUES,
-    ENABLE_UNDEFINED
+    ENABLE_UNDEFINED,
 }
 MAX_NUMBER_OF_INSTANCES_TO_VERIFY_UNIQUENESS = 100000
+INDEX = "    "
